@@ -1,6 +1,20 @@
 package ALPM::DB;
 
 use ALPM;
+use Carp qw(croak);
+
+# Wrapper to automatically create a transaction...
+sub update
+{
+    my $self = shift;
+
+    croak "unable to update database while a transaction is in process"
+        if ( $ALPM::_Transaction );
+
+    my $t = ALPM->transaction( type => 'sync' );
+    $self->_update(1);
+    $t = undef;
+}
 
 # Wrapper to keep ALPM from crashing...
 sub get_url
@@ -11,6 +25,21 @@ sub get_url
     return $self->_get_url;
 }
 
+# Wrapper so people don't have to use arrayrefs.
+sub search
+{
+    my $self = shift;
+
+    my $results = eval { $self->_search( [ @_ ] ) };
+    if ( $@ ) {
+        die "$@\n" unless ( $@ =~ /\AALPM Error:/ );
+        $@ =~ s/ at .*? line \d+[.]\n//;
+        croak $@;
+    }
+
+    return $results;
+}
+
 1;
 
 =head1 NAME
@@ -21,7 +50,7 @@ ALPM::DB - Class to represent a libalpm database
 
   ... load ALPM with options first ...
 
-  my $localdb = ALPM->register_db;
+  my $localdb = ALPM->local_db;
   my $name    = $localdb->get_name;
   my $perl    = $localdb->get_pkg('perl');
 
@@ -43,7 +72,7 @@ ALPM::DB - Class to represent a libalpm database
   Returns : The name of the repository database.
             Ex: core, extra, community, etc...
 
-=head1 get_url
+=head2 get_url
 
   Usage   : my $url = $db->get_url;
   Returns : The url of the repository, the same one the DB
@@ -59,8 +88,8 @@ ALPM::DB - Class to represent a libalpm database
 
 =head2 search
 
-  Usage   : my $results_ref = $db->search([ 'foo', 'bar', ... ]);
-  Params  : An arrayref of the strings to search for.
+  Usage   : my $results_ref = $db->search( 'foo', 'bar', ... );
+  Params  : A list of strings to search for.
   Returns : An arrayref of package objects that matched the search.
 
 =head2 get_pkg_cache
@@ -68,9 +97,21 @@ ALPM::DB - Class to represent a libalpm database
   Usage   : my $cache_ref = $db->get_pkg_cache;
   Returns : An arrayref of package objects in the DB cache.
 
+=head2 update
+
+  Usage   : $db->update;
+  Purpose : Updates the local copy of the database's package list.
+  Comment : This needs to create a transaction to work, so make sure
+            you don't have any active transactions.
+
+            Things may work incorrectly if the database is not updated.
+            If there is no local db copy, the package cache will be empty.
+  Returns : 1
+  TODO    : Provide different return values like alpm does.
+
 =head1 SEE ALSO
 
-L<ALPM>, L<ALPM::Package>
+L<ALPM>, L<ALPM::Package>, L<ALPM::Transaction>
 
 =head1 AUTHOR
 
